@@ -14,11 +14,9 @@
 
 import os
 import tempfile
-import time
 
 import mock
 from oslo_concurrency import processutils
-import requests
 
 from ironic_python_agent import errors
 from ironic_python_agent.extensions import standby
@@ -152,7 +150,7 @@ class TestStandbyExtension(base.IronicAgentTest):
         expected_loc = os.path.join(tempfile.gettempdir(), 'fake_id')
         self.assertEqual(expected_loc, location)
 
-    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('builtins.open', autospec=True)
     @mock.patch('ironic_python_agent.utils.execute', autospec=True)
     def test_write_image(self, execute_mock, open_mock):
         image_info = _build_fake_image_info()
@@ -177,7 +175,7 @@ class TestStandbyExtension(base.IronicAgentTest):
         execute_mock.assert_called_once_with(*command, check_exit_code=[0])
 
     @mock.patch.object(hardware, 'dispatch_to_managers', autospec=True)
-    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('builtins.open', autospec=True)
     @mock.patch('ironic_python_agent.utils.execute', autospec=True)
     @mock.patch('ironic_lib.disk_utils.get_image_mb', autospec=True)
     @mock.patch('ironic_lib.disk_utils.work_on_disk', autospec=True)
@@ -223,7 +221,7 @@ class TestStandbyExtension(base.IronicAgentTest):
                                                   cpu_arch=cpu_arch)
 
     @mock.patch.object(hardware, 'dispatch_to_managers', autospec=True)
-    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('builtins.open', autospec=True)
     @mock.patch('ironic_python_agent.utils.execute', autospec=True)
     @mock.patch('ironic_lib.disk_utils.get_image_mb', autospec=True)
     @mock.patch('ironic_lib.disk_utils.work_on_disk', autospec=True)
@@ -273,7 +271,7 @@ class TestStandbyExtension(base.IronicAgentTest):
         self.assertIsNone(node_uuid)
 
     @mock.patch.object(hardware, 'dispatch_to_managers', autospec=True)
-    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('builtins.open', autospec=True)
     @mock.patch('ironic_python_agent.utils.execute', autospec=True)
     @mock.patch('ironic_lib.disk_utils.get_image_mb', autospec=True)
     @mock.patch('ironic_lib.disk_utils.work_on_disk', autospec=True)
@@ -298,7 +296,7 @@ class TestStandbyExtension(base.IronicAgentTest):
         self.assertFalse(work_on_disk_mock.called)
 
     @mock.patch.object(hardware, 'dispatch_to_managers', autospec=True)
-    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('builtins.open', autospec=True)
     @mock.patch('ironic_python_agent.utils.execute', autospec=True)
     @mock.patch('ironic_lib.disk_utils.work_on_disk', autospec=True)
     @mock.patch('ironic_lib.disk_utils.get_image_mb', autospec=True)
@@ -342,7 +340,7 @@ class TestStandbyExtension(base.IronicAgentTest):
         self.assertEqual(expected_uuid, work_on_disk_mock.return_value)
 
     @mock.patch('hashlib.md5', autospec=True)
-    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('builtins.open', autospec=True)
     @mock.patch('requests.get', autospec=True)
     def test_download_image(self, requests_mock, open_mock, md5_mock):
         image_info = _build_fake_image_info()
@@ -358,15 +356,14 @@ class TestStandbyExtension(base.IronicAgentTest):
         standby._download_image(image_info)
         requests_mock.assert_called_once_with(image_info['urls'][0],
                                               cert=None, verify=True,
-                                              stream=True, proxies={},
-                                              timeout=60)
+                                              stream=True, proxies={})
         write = file_mock.write
         write.assert_any_call('some')
         write.assert_any_call('content')
         self.assertEqual(2, write.call_count)
 
     @mock.patch('hashlib.md5', autospec=True)
-    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('builtins.open', autospec=True)
     @mock.patch('requests.get', autospec=True)
     @mock.patch.dict(os.environ, {})
     def test_download_image_proxy(
@@ -390,8 +387,7 @@ class TestStandbyExtension(base.IronicAgentTest):
         self.assertEqual(no_proxy, os.environ['no_proxy'])
         requests_mock.assert_called_once_with(image_info['urls'][0],
                                               cert=None, verify=True,
-                                              stream=True, proxies=proxies,
-                                              timeout=60)
+                                              stream=True, proxies=proxies)
         write = file_mock.write
         write.assert_any_call('some')
         write.assert_any_call('content')
@@ -399,7 +395,6 @@ class TestStandbyExtension(base.IronicAgentTest):
 
     @mock.patch('requests.get', autospec=True)
     def test_download_image_bad_status(self, requests_mock):
-        self.config(image_download_connection_retry_interval=0)
         image_info = _build_fake_image_info()
         response = requests_mock.return_value
         response.status_code = 404
@@ -408,7 +403,7 @@ class TestStandbyExtension(base.IronicAgentTest):
                           image_info)
 
     @mock.patch('hashlib.md5', autospec=True)
-    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('builtins.open', autospec=True)
     @mock.patch('requests.get', autospec=True)
     def test_download_image_verify_fails(self, requests_mock, open_mock,
                                          md5_mock):
@@ -422,7 +417,7 @@ class TestStandbyExtension(base.IronicAgentTest):
                           image_info)
 
     @mock.patch('hashlib.md5', autospec=True)
-    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('builtins.open', autospec=True)
     @mock.patch('requests.get', autospec=True)
     def test_verify_image_success(self, requests_mock, open_mock, md5_mock):
         image_info = _build_fake_image_info()
@@ -435,7 +430,7 @@ class TestStandbyExtension(base.IronicAgentTest):
         image_download.verify_image(image_location)
 
     @mock.patch('hashlib.new', autospec=True)
-    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('builtins.open', autospec=True)
     @mock.patch('requests.get', autospec=True)
     def test_verify_image_success_with_new_hash_fields(self, requests_mock,
                                                        open_mock,
@@ -453,7 +448,7 @@ class TestStandbyExtension(base.IronicAgentTest):
         hashlib_mock.assert_called_with('sha512')
 
     @mock.patch('hashlib.new', autospec=True)
-    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('builtins.open', autospec=True)
     @mock.patch('requests.get', autospec=True)
     def test_verify_image_success_without_md5(self, requests_mock,
                                               open_mock, hashlib_mock):
@@ -471,7 +466,7 @@ class TestStandbyExtension(base.IronicAgentTest):
         hashlib_mock.assert_called_with('sha512')
 
     @mock.patch('hashlib.md5', autospec=True)
-    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('builtins.open', autospec=True)
     @mock.patch('requests.get', autospec=True)
     def test_verify_image_success_with_md5_fallback(self, requests_mock,
                                                     open_mock, md5_mock):
@@ -487,7 +482,7 @@ class TestStandbyExtension(base.IronicAgentTest):
         image_download.verify_image(image_location)
 
     @mock.patch('hashlib.new', autospec=True)
-    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('builtins.open', autospec=True)
     @mock.patch('requests.get', autospec=True)
     def test_verify_image_failure_with_new_hash_fields(self, requests_mock,
                                                        open_mock,
@@ -507,7 +502,7 @@ class TestStandbyExtension(base.IronicAgentTest):
         hashlib_mock.assert_called_with('sha512')
 
     @mock.patch('hashlib.md5', autospec=True)
-    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('builtins.open', autospec=True)
     @mock.patch('requests.get', autospec=True)
     def test_verify_image_failure(self, requests_mock, open_mock, md5_mock):
         image_info = _build_fake_image_info()
@@ -522,7 +517,7 @@ class TestStandbyExtension(base.IronicAgentTest):
                           image_location)
 
     @mock.patch('hashlib.new', autospec=True)
-    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('builtins.open', autospec=True)
     @mock.patch('requests.get', autospec=True)
     def test_verify_image_failure_without_fallback(self, requests_mock,
                                                    open_mock, hashlib_mock):
@@ -1052,7 +1047,7 @@ class TestStandbyExtension(base.IronicAgentTest):
         write_mock.assert_called_once_with(image_info, device)
 
     @mock.patch('hashlib.md5', autospec=True)
-    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('builtins.open', autospec=True)
     @mock.patch('requests.get', autospec=True)
     def test_stream_raw_image_onto_device(self, requests_mock, open_mock,
                                           md5_mock):
@@ -1070,18 +1065,15 @@ class TestStandbyExtension(base.IronicAgentTest):
                                                            '/dev/foo')
         requests_mock.assert_called_once_with(image_info['urls'][0],
                                               cert=None, verify=True,
-                                              stream=True, proxies={},
-                                              timeout=60)
+                                              stream=True, proxies={})
         expected_calls = [mock.call('some'), mock.call('content')]
         file_mock.write.assert_has_calls(expected_calls)
 
     @mock.patch('hashlib.md5', autospec=True)
-    @mock.patch('six.moves.builtins.open', autospec=True)
+    @mock.patch('builtins.open', autospec=True)
     @mock.patch('requests.get', autospec=True)
     def test_stream_raw_image_onto_device_write_error(self, requests_mock,
                                                       open_mock, md5_mock):
-        self.config(image_download_connection_timeout=1)
-        self.config(image_download_connection_retry_interval=0)
         image_info = _build_fake_image_info()
         response = requests_mock.return_value
         response.status_code = 200
@@ -1095,20 +1087,11 @@ class TestStandbyExtension(base.IronicAgentTest):
         self.assertRaises(errors.ImageDownloadError,
                           self.agent_extension._stream_raw_image_onto_device,
                           image_info, '/dev/foo')
-        calls = [mock.call('http://example.org', cert=None, proxies={},
-                           stream=True, timeout=1, verify=True),
-                 mock.call().iter_content(mock.ANY),
-                 mock.call('http://example.org', cert=None, proxies={},
-                           stream=True, timeout=1, verify=True),
-                 mock.call().iter_content(mock.ANY),
-                 mock.call('http://example.org', cert=None, proxies={},
-                           stream=True, timeout=1, verify=True),
-                 mock.call().iter_content(mock.ANY)]
-        requests_mock.assert_has_calls(calls)
-        write_calls = [mock.call('some'),
-                       mock.call('some'),
-                       mock.call('some')]
-        file_mock.write.assert_has_calls(write_calls)
+        requests_mock.assert_called_once_with(image_info['urls'][0],
+                                              cert=None, verify=True,
+                                              stream=True, proxies={})
+        # Assert write was only called once and failed!
+        file_mock.write.assert_called_once_with('some')
 
     @mock.patch('ironic_lib.disk_utils.get_disk_identifier',
                 lambda dev: 'ROOT')
@@ -1123,71 +1106,6 @@ class TestStandbyExtension(base.IronicAgentTest):
                         '/dev/fake root_uuid=ROOT')
         self.assertEqual(expected_msg, result_msg)
 
-    @mock.patch('ironic_lib.disk_utils.fix_gpt_partition', autospec=True)
-    @mock.patch('hashlib.md5', autospec=True)
-    @mock.patch('six.moves.builtins.open', autospec=True)
-    @mock.patch('requests.get', autospec=True)
-    def test_stream_raw_image_onto_device_socket_read_timeout(
-            self, requests_mock, open_mock, md5_mock, fix_gpt_mock):
-
-        class create_timeout(object):
-            status_code = 200
-
-            def __init__(self, url, stream, proxies, verify, cert, timeout):
-                time.sleep(1)
-                self.count = 0
-
-            def __iter__(self):
-                return self
-
-            def __next__(self):
-                if self.count:
-                    time.sleep(0.1)
-                    return None
-                if self.count < 3:
-                    self.count += 1
-                    return "meow"
-                else:
-                    time.sleep(30)
-                    raise StopIteration
-
-            # Python 2
-            next = __next__
-
-            def iter_content(self, chunk_size):
-                return self
-
-        self.config(image_download_connection_timeout=1)
-        self.config(image_download_connection_retries=2)
-        self.config(image_download_connection_retry_interval=0)
-        image_info = _build_fake_image_info()
-        file_mock = mock.Mock()
-        open_mock.return_value.__enter__.return_value = file_mock
-        file_mock.read.return_value = None
-        hexdigest_mock = md5_mock.return_value.hexdigest
-        hexdigest_mock.return_value = image_info['checksum']
-        requests_mock.side_effect = create_timeout
-        self.assertRaisesRegex(
-            errors.ImageDownloadError,
-            'Timed out reading next chunk',
-            self.agent_extension._stream_raw_image_onto_device,
-            image_info,
-            '/dev/foo')
-
-        calls = [mock.call(image_info['urls'][0], cert=None, verify=True,
-                           stream=True, proxies={}, timeout=1),
-                 mock.call(image_info['urls'][0], cert=None, verify=True,
-                           stream=True, proxies={}, timeout=1),
-                 mock.call(image_info['urls'][0], cert=None, verify=True,
-                           stream=True, proxies={}, timeout=1)]
-        requests_mock.assert_has_calls(calls)
-
-        write_calls = [mock.call('meow'),
-                       mock.call('meow'),
-                       mock.call('meow')]
-        file_mock.write.assert_has_calls(write_calls)
-        self.assertFalse(fix_gpt_mock.called)
-
     def test__message_format_partition_bios(self):
         image_info = _build_fake_partition_image_info()
         msg = ('image ({}) already present on device {} ')
@@ -1262,13 +1180,11 @@ class TestImageDownload(base.IronicAgentTest):
         self.assertEqual(content, list(image_download))
         requests_mock.assert_called_once_with(image_info['urls'][0],
                                               cert=None, verify=True,
-                                              stream=True, proxies={},
-                                              timeout=60)
+                                              stream=True, proxies={})
         self.assertEqual(image_info['checksum'],
                          image_download._hash_algo.hexdigest())
 
-    @mock.patch('time.sleep', autospec=True)
-    def test_download_image_fail(self, sleep_mock, requests_mock, time_mock):
+    def test_download_image_fail(self, requests_mock, time_mock):
         response = requests_mock.return_value
         response.status_code = 401
         response.text = 'Unauthorized'
@@ -1282,57 +1198,7 @@ class TestImageDownload(base.IronicAgentTest):
                                standby.ImageDownload, image_info)
         requests_mock.assert_called_once_with(image_info['urls'][0],
                                               cert=None, verify=True,
-                                              stream=True, proxies={},
-                                              timeout=60)
-        self.assertFalse(sleep_mock.called)
-
-    @mock.patch('time.sleep', autospec=True)
-    def test_download_image_retries(self, sleep_mock, requests_mock,
-                                    time_mock):
-        self.config(image_download_connection_retries=2)
-        response = requests_mock.return_value
-        response.status_code = 500
-        response.text = 'Oops'
-        time_mock.return_value = 0.0
-        image_info = _build_fake_image_info()
-        msg = ('Error downloading image: Download of image fake_id failed: '
-               'URL: http://example.org; time: .* seconds. Error: '
-               'Received status code 500 from http://example.org, expected '
-               '200. Response body: Oops')
-        self.assertRaisesRegex(errors.ImageDownloadError, msg,
-                               standby.ImageDownload, image_info)
-        requests_mock.assert_called_with(image_info['urls'][0],
-                                         cert=None, verify=True,
-                                         stream=True, proxies={},
-                                         timeout=60)
-        self.assertEqual(3, requests_mock.call_count)
-        sleep_mock.assert_called_with(10)
-        self.assertEqual(2, sleep_mock.call_count)
-
-    @mock.patch('time.sleep', autospec=True)
-    def test_download_image_retries_success(self, sleep_mock, requests_mock,
-                                            md5_mock):
-        content = ['SpongeBob', 'SquarePants']
-        fail_response = mock.Mock()
-        fail_response.status_code = 500
-        fail_response.text = " "
-        response = mock.Mock()
-        response.status_code = 200
-        response.iter_content.return_value = content
-        requests_mock.side_effect = [requests.Timeout, fail_response, response]
-
-        image_info = _build_fake_image_info()
-        md5_mock.return_value.hexdigest.return_value = image_info['checksum']
-        image_download = standby.ImageDownload(image_info)
-
-        self.assertEqual(content, list(image_download))
-        requests_mock.assert_called_with(image_info['urls'][0],
-                                         cert=None, verify=True,
-                                         stream=True, proxies={},
-                                         timeout=60)
-        self.assertEqual(3, requests_mock.call_count)
-        sleep_mock.assert_called_with(10)
-        self.assertEqual(2, sleep_mock.call_count)
+                                              stream=True, proxies={})
 
     def test_download_image_and_checksum(self, requests_mock, md5_mock):
         content = ['SpongeBob', 'SquarePants']
@@ -1353,9 +1219,9 @@ class TestImageDownload(base.IronicAgentTest):
         self.assertEqual(content, list(image_download))
         requests_mock.assert_has_calls([
             mock.call('http://example.com/checksum', cert=None, verify=True,
-                      stream=True, proxies={}, timeout=60),
+                      stream=True, proxies={}),
             mock.call(image_info['urls'][0], cert=None, verify=True,
-                      stream=True, proxies={}, timeout=60),
+                      stream=True, proxies={}),
         ])
         self.assertEqual(fake_cs, image_download._hash_algo.hexdigest())
 
@@ -1383,9 +1249,9 @@ foobar  irrelevant file.img
         self.assertEqual(content, list(image_download))
         requests_mock.assert_has_calls([
             mock.call('http://example.com/checksum', cert=None, verify=True,
-                      stream=True, proxies={}, timeout=60),
+                      stream=True, proxies={}),
             mock.call(image_info['urls'][0], cert=None, verify=True,
-                      stream=True, proxies={}, timeout=60),
+                      stream=True, proxies={}),
         ])
         self.assertEqual(fake_cs, image_download._hash_algo.hexdigest())
 
@@ -1431,7 +1297,6 @@ foobar  irrelevant file.img
                                standby.ImageDownload, image_info)
 
     def test_download_image_and_checksum_failed(self, requests_mock, md5_mock):
-        self.config(image_download_connection_retry_interval=0)
         content = ['SpongeBob', 'SquarePants']
         cs_response = mock.Mock()
         cs_response.status_code = 400
@@ -1439,9 +1304,7 @@ foobar  irrelevant file.img
         response = mock.Mock()
         response.status_code = 200
         response.iter_content.return_value = content
-        # 3 retries on status code
-        requests_mock.side_effect = [cs_response, cs_response, cs_response,
-                                     response]
+        requests_mock.side_effect = [cs_response, response]
 
         image_info = _build_fake_image_info(
             'http://example.com/path/image.img')
