@@ -226,11 +226,17 @@ class BaseDiscoverTest(base.IronicAgentTest):
         self.data = {}
 
 
+@mock.patch.object(hardware, 'get_managers', autospec=True)
 @mock.patch.object(inspector, 'wait_for_dhcp', autospec=True)
 @mock.patch.object(hardware, 'dispatch_to_managers', autospec=True)
 class TestCollectDefault(BaseDiscoverTest):
-    def test_ok(self, mock_dispatch, mock_wait_for_dhcp):
+    def test_ok(self, mock_dispatch, mock_wait_for_dhcp, mock_get_mgrs):
+        mgrs = [{'name': 'extra', 'version': '1.42'},
+                {'name': 'generic', 'version': '1.1'}]
         mock_dispatch.return_value = self.inventory
+        mock_get_mgrs.return_value = [
+            mock.Mock(**{'get_version.return_value': item}) for item in mgrs
+        ]
 
         inspector.collect_default(self.data, self.failures)
 
@@ -240,21 +246,21 @@ class TestCollectDefault(BaseDiscoverTest):
         self.assertEqual('boot:if', self.data['boot_interface'])
         self.assertEqual(self.inventory['disks'][2].name,
                          self.data['root_disk'].name)
+        self.assertEqual({'collectors': ['default'], 'managers': mgrs},
+                         self.data['configuration'])
 
         mock_dispatch.assert_called_once_with('list_hardware_info')
         mock_wait_for_dhcp.assert_called_once_with()
 
-    def test_cache_hardware_info(self, mock_dispatch, mock_wait_for_dhcp):
-        mock_dispatch.return_value = self.inventory
-
-        inspector.collect_default(self.data, self.failures)
-        inspector.collect_default(self.data, self.failures)
-        # Hardware is cached, so only one call is made
-        mock_dispatch.assert_called_once_with('list_hardware_info')
-
-    def test_no_root_disk(self, mock_dispatch, mock_wait_for_dhcp):
+    def test_no_root_disk(self, mock_dispatch, mock_wait_for_dhcp,
+                          mock_get_mgrs):
+        mgrs = [{'name': 'extra', 'version': '1.42'},
+                {'name': 'generic', 'version': '1.1'}]
         mock_dispatch.return_value = self.inventory
         self.inventory['disks'] = []
+        mock_get_mgrs.return_value = [
+            mock.Mock(**{'get_version.return_value': item}) for item in mgrs
+        ]
 
         inspector.collect_default(self.data, self.failures)
 
@@ -263,6 +269,8 @@ class TestCollectDefault(BaseDiscoverTest):
 
         self.assertEqual('boot:if', self.data['boot_interface'])
         self.assertNotIn('root_disk', self.data)
+        self.assertEqual({'collectors': ['default'], 'managers': mgrs},
+                         self.data['configuration'])
 
         mock_dispatch.assert_called_once_with('list_hardware_info')
         mock_wait_for_dhcp.assert_called_once_with()
@@ -349,7 +357,7 @@ class TestCollectPciDevicesInfo(base.IronicAgentTest):
                                 {'vendor_id': '9876', 'product_id': '5432'}]
 
         mock_open = mock.mock_open()
-        with mock.patch('six.moves.builtins.open', mock_open):
+        with mock.patch('builtins.open', mock_open):
             mock_read = mock_open.return_value.read
             mock_read.side_effect = reads
             inspector.collect_pci_devices_info(self.data, self.failures)
@@ -375,7 +383,7 @@ class TestCollectPciDevicesInfo(base.IronicAgentTest):
         expected_pci_devices = [{'vendor_id': '1234', 'product_id': '5678'}]
 
         mock_open = mock.mock_open()
-        with mock.patch('six.moves.builtins.open', mock_open):
+        with mock.patch('builtins.open', mock_open):
             mock_read = mock_open.return_value.read
             mock_read.side_effect = reads
             inspector.collect_pci_devices_info(self.data, self.failures)
